@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2012 by the Quassel Project                        *
+ *   Copyright (C) 2005-2013 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
 #ifndef COREIRCUSER_H_
@@ -27,25 +27,27 @@
 #  include "cipher.h"
 #endif
 
-class CoreIrcUser : public IrcUser {
-  SYNCABLE_OBJECT
-  Q_OBJECT
+class CoreIrcUser : public IrcUser
+{
+    SYNCABLE_OBJECT
+        Q_OBJECT
 
 public:
-  CoreIrcUser(const QString &hostmask, Network *network);
-  virtual ~CoreIrcUser();
+    CoreIrcUser(const QString &hostmask, Network *network);
+    virtual ~CoreIrcUser();
 
-  inline virtual const QMetaObject *syncMetaObject() const { return &IrcUser::staticMetaObject; }
+    inline virtual const QMetaObject *syncMetaObject() const { return &IrcUser::staticMetaObject; }
 
 #ifdef HAVE_QCA2
-  Cipher *cipher() const;
-  void setEncrypted(bool);
+    Cipher *cipher() const;
+    void setEncrypted(bool);
 #endif
 
 #ifdef HAVE_QCA2
 private:
-  mutable Cipher *_cipher;
+    mutable Cipher *_cipher;
 #endif
 };
 
+
 #endif
